@@ -7,7 +7,7 @@ from tqdm import tqdm
 from mrftools import DictionaryParameters, SequenceParameters
 
 class Simulation: 
-    def __init__(self,sequenceParameters, dictionaryParameters, name="", numTimepoints = -1, phaseRange=(-2*np.pi, 2*np.pi), numSpins=1, results=[], truncationMatrix=[], truncatedResults=[], singularValues=[], intialMz=-0.95):
+    def __init__(self,sequenceParameters, dictionaryParameters, name="", numTimepoints = -1, phaseRange=(-2*np.pi, 2*np.pi), numSpins=1, results=[], truncationMatrix=[], truncatedResults=[], singularValues=[], initialMz=-0.95):
         self.sequenceParameters = sequenceParameters
         self.dictionaryParameters = dictionaryParameters
         if numTimepoints == -1:
@@ -19,7 +19,7 @@ class Simulation:
         self.truncationMatrix = truncationMatrix
         self.truncatedResults = truncatedResults
         self.singularValues = singularValues
-        self.initialMz = intialMz
+        self.initialMz = initialMz
         if not name:
             self.name = sequenceParameters.name + "_" + dictionaryParameters.name + "_" + str(numSpins) # Doesn't account for phase range
         else:
